@@ -2,6 +2,7 @@
 # vim: et ts=4 sw=4 sts=4
 
 import unittest
+import subprocess
 import sys
 import logging
 from logging import debug
@@ -10,6 +11,7 @@ from StringIO import StringIO
 from collections import namedtuple
 
 from fakelvm import FakeLVM
+from imgbased import utils
 
 from imgbased import CliApplication
 import imgbased
@@ -25,7 +27,6 @@ class ImgbaseTestCase(unittest.TestCase):
         pool = FakeLVM.Thinpool()
         pool.vg_name = vg.vg_name
         pool.lv_name = "pool0"
-        pool.size = 10*1024
         vg._lvs.add(pool)
 
         pool.create_thinvol("root", 10)
@@ -45,7 +46,6 @@ class CliTestCase(ImgbaseTestCase):
                 patch("imgbased.imgbase.LVM", FakeLVM), \
                 patch("imgbased.imgbase.Hooks"), \
                 patch("imgbased.imgbase.utils.Filesystem"), \
-                patch("imgbased.plugins.core.augtool"), \
                 patch("imgbased.imgbase.ImageLayers.current_layer",
                       lambda s: None):
             try:
@@ -78,6 +78,44 @@ class CliTestCase(ImgbaseTestCase):
                  "--from", "hostvg/root")
 
 
+class FindmntTestCase(CliTestCase):
+    def test_findmnt(self):
+        CliTestCase.assertIsNone(self,
+                                 utils.findmnt(["SOURCE", "/tmp/_fake_dir_"]))
+
+    def test_find_mount_target(self):
+        CliTestCase.assertTrue(self, utils.find_mount_target())
+
+    def test_find_mount_source(self):
+        CliTestCase.assertIsNone(self,
+                                 utils.find_mount_source("/tmp/_fake_dir_"))
+
+
+class FilesystemTestCase(CliTestCase):
+    def test_supported_filesystem(self):
+        supported_fs = ['ext4', 'xfs']
+        fs = utils.Filesystem.supported_filesystem()
+        CliTestCase.assertEqual(self, supported_fs, fs)
+
+    def test_get_type(self):
+        with self.assertRaises(subprocess.CalledProcessError):
+            # Command will fail because there is no _fake_vg_ to check
+            CliTestCase.assertTrue(self, utils.Filesystem.get_type(
+                                   "/dev/mapper/_fake_vg_"))
+
+    def test_from_device(self):
+        # Command will fail because there is no _fake_vg_ to check
+        with self.assertRaises(subprocess.CalledProcessError):
+            CliTestCase.assertTrue(self, utils.Filesystem.from_device(
+                                   "/dev/mapper/_fake_vg_"))
+
+    def test_from_mountpoint(self):
+        with self.assertRaises(subprocess.CalledProcessError):
+            # Command will fail because there is no _fake_mountpoint__ to check
+            CliTestCase.assertTrue(self, utils.Filesystem.from_mountpoint(
+                                   "/_fake_mountpoint_"))
+
+
 class LayoutVerbTestCase(CliTestCase):
     def test_layout_init_from(self):
         debug("LVs: %s" % FakeLVM.lvs())
